@@ -20,11 +20,13 @@ class AuthError(Exception):
 class BaseAuthBackend(ABC):
 
 
-    def __init__(self, host, port, protocol="http", token_url="o/token", check_endpoint="auth/") -> None:
+    def __init__(self, host, port, protocol="http", token_url="o/token", check_endpoint="auth/", scopes=None, **kwargs) -> None:
 
         self.base_url = f"{protocol}://{host}:{port}/"
         self.check_url = self.base_url + check_endpoint
-
+        self.scopes = scopes + ["introspection"] if scopes else ["introspection"]
+        print(self.scopes)
+        self.scope = " ".join(self.scopes)
 
         config_name = "access.cfg"
         run_path = os.path.abspath(os.getcwd())
@@ -59,7 +61,8 @@ class BaseAuthBackend(ABC):
         
         else:
             if self.needs_validation:
-                response = requests.get(self.check_url, headers={"Authorization": f"Bearer: {self.token}"})
+                response = requests.post(self.check_url, {"token": self.token}, headers={"Authorization": f"Bearer {self.token}"})
+                print(response.status_code)
                 self.needs_validation = False
                 if response.status_code == 200:
                     logger.info("Old token still valid!")
@@ -67,6 +70,10 @@ class BaseAuthBackend(ABC):
                 else:
                     logger.info("Need to refetch Token!!") # Was no longer valid, fetching anew
                     self.token = self.fetchToken()
+
+                    with shelve.open(self.config_path) as cfg:
+                        cfg['token'] = self.token
+
                     return self.token
                 
             return self.token
