@@ -1,6 +1,7 @@
 import asyncio
+from typing import Dict
 from bergen.wards.graphql.aiohttp import AIOHttpGraphQLWard
-from bergen.enums import ClientType
+from bergen.enums import ClientType, PostmanProtocol
 from bergen.logging import setLogging
 from bergen.auths.base import BaseAuthBackend
 from bergen.wards.base import BaseWard
@@ -18,7 +19,7 @@ def start_background_loop(loop: asyncio.AbstractEventLoop) -> None:
 class BaseBergen:
 
 
-    def __init__(self, auth: BaseAuthBackend= None, host: str = None, port: int = None, ssl=False, auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = None, jupyter=False, force_sync = False, **kwargs) -> None:
+    def __init__(self, auth: BaseAuthBackend= None, host: str = None, port: int = None, ssl=False, auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = ClientType.CLIENT, jupyter=False, force_sync = False, **kwargs) -> None:
         
 
         if jupyter:
@@ -71,7 +72,7 @@ class BaseBergen:
 
         self._transcript = None
         self.identifierDataPointMap = {}
-        self.identifierWardMap: dict[str, BaseWard] = {}
+        self.identifierWardMap: Dict[str, BaseWard] = {}
 
 
         if auto_negotiate == True:
@@ -97,6 +98,9 @@ class BaseBergen:
         return self.transcript.extensions[extension]
 
     def getWardForIdentifier(self, identifier):
+        if identifier in ["node","template","pod"]:
+            return self.main_ward
+
         if self._transcript is None:
             if self.running_in_sync:
                 raise Exception("Not negotiated Error: Please negotiate first or set auto_negotiate=True")
@@ -106,13 +110,13 @@ class BaseBergen:
         if identifier in self.identifierWardMap:
             return self.identifierWardMap[identifier]
         else:
-            return self.main_ward
+            raise Exception(f"Couldn't find a Ward/Datapoint for Model {identifier}, this mostly results from importing a schema that isn't part of your arkitekts configuration ..Check Documentaiton")
 
 
     def getPostmanFromSettings(self, transcript):
         settings = transcript.postman
 
-        if settings.type == "pika":
+        if settings.type == PostmanProtocol.RABBITMQ:
             try:
                 from bergen.postmans.pika import PikaPostman
                 postman = PikaPostman(**settings.kwargs, loop=self.loop)
@@ -120,7 +124,7 @@ class BaseBergen:
                 logger.error("You cannot use the Pika Postman without installing aio_pika")
                 raise e
 
-        elif settings.type == "websocket":
+        elif settings.type == PostmanProtocol.WEBSOCKET:
             try:
                 from bergen.postmans.websocket import WebsocketPostman
                 postman = WebsocketPostman(**settings.kwargs, loop=self.loop)
@@ -143,8 +147,8 @@ class BaseBergen:
         await self.main_ward.configure()
 
         # We resort escalating to the different client Type protocols
-        clientType = client_type or self.client_type or self.auth.getClientType()
-        self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": clientType, "local": self.local})
+        clientType = client_type or self.client_type
+        self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": clientType})
         
 
         #Lets create our different Wards 
