@@ -1,9 +1,10 @@
 from asyncio.tasks import ensure_future
+from bergen.messages.postman.assign import AssignMessage
 from bergen.messages.provision_request import ProvisionRequestMessage
 from bergen.utils import expandOutputs, shrinkInputs
 from bergen.messages.assignation import AssignationMessage
 from bergen.messages.provision import ProvisionMessage
-from bergen.messages.exceptions.base import ExceptionMessage
+from bergen.messages.exception import ExceptionMessage
 from bergen.messages.types import ASSIGNATION, EXCEPTION, PROVISION
 from bergen.messages.base import MessageModel
 from bergen.messages.assignation_request import AssignationAction, AssignationRequestMessage
@@ -65,6 +66,7 @@ class WebsocketPostman(BasePostman):
         self.configured = False
         self.consumer_task = None
         self.producer_task = None
+        self.sending_task = None
 
         self.assign_routing = "assignation_request"
         self.active_stream_queues = {}
@@ -73,6 +75,8 @@ class WebsocketPostman(BasePostman):
     async def configure(self):
         self.callback_queue = asyncio.Queue()
         self.progress_queue = asyncio.Queue()
+
+        self.send_queue = asyncio.Queue()
         self.tasks = []
         self.startup_task = create_task(self.startup())
 
@@ -83,31 +87,39 @@ class WebsocketPostman(BasePostman):
         if self.startup_task: self.startup_task.cancel()
         if self.consumer_task: self.consumer_task.cancel()
         if self.producer_task: self.producer_task.cancel()
-        print("Bergen disconnected")
+        if self.sending_task: self.sending_task.cancel()
+        logger.info("Postman disconnected")
 
     async def startup(self):
         try:
             await self.connect_websocket()
-        except:
+        except Exception as e:
+            logger.info(e)
             self.current_retries += 1
             if self.current_retries < self.allowed_retries:
                 sleeping_time = (self.current_retries + 1)
-                logger.error(f"Initial Connection failing: Trying again in {sleeping_time} seconds")
+                logger.error(f"Initial Connection failing: Trying again in {sleeping_time} seconds {e}")
                 await asyncio.sleep(sleeping_time)
                 await self.startup()
             else:
                 return
 
 
-        self.consumer_task = create_task(
-            self.producer()
+        self.receiving_task = create_task(
+            self.receiving()
         )
+
+        self.sending_task = create_task(
+            self.sending()
+        )
+
+
         self.producer_task = create_task(
             self.workers()
         )
 
         done, pending = await asyncio.wait(
-            [self.consumer_task, self.producer_task],
+            [self.producer_task, self.receiving_task, self.sending_task],
             return_when=asyncio.FIRST_EXCEPTION
         )
 
@@ -122,17 +134,23 @@ class WebsocketPostman(BasePostman):
 
 
     async def connect_websocket(self):
-        try:
-            self.connection = await websockets.client.connect(self.uri)
-        except ConnectionRefusedError:
-            raise
+        self.connection = await websockets.client.connect(self.uri)
+        
 
-
-    async def producer(self):
+    async def receiving(self):
         logger.info(" [x] Awaiting Reponse from Postman")
         async for message in self.connection:
             await self.callback_queue.put(message)
-        # await self.send_queue.put(message)
+    
+
+    async def sending(self):
+        while True:
+            message = await self.send_queue.get()
+            if self.connection:
+                await self.connection.send(message.to_channels())
+            else:
+                raise Exception("No longer connected. Did you use an Async context manager?")
+
 
     async def workers(self):
         while True:
@@ -144,7 +162,7 @@ class WebsocketPostman(BasePostman):
                 if parsed_message.meta.type == EXCEPTION: #Protocol Exception
                     parsed_exception = ExceptionMessage.from_channels(message=message)
                     future = self.futures.pop(parsed_exception.meta.reference)
-                    future.set_exception(Exception(parsed_exception.data.message))
+                    future.set_exception(parsed_exception.toException())
 
 
                 elif parsed_message.meta.type == ASSIGNATION: # Assignation Exception
@@ -201,7 +219,7 @@ class WebsocketPostman(BasePostman):
 
         self.active_stream_queues[correlation_id] = asyncio.Queue()
 
-        request = AssignationRequestMessage(data={
+        request = AssignMessage(data={
                                                 "node":node.id, 
                                                 "inputs": assigned_inputs, 
                                                 "params": dict(params or {}),
@@ -272,11 +290,7 @@ class WebsocketPostman(BasePostman):
 
 
     async def send_to_arnheim(self,request):
-        if self.connection:
-            await self.connection.send(request.to_channels())
-        else:
-            raise Exception("No longer connected. Did you use an Async context manager?")
-        
+        await self.send_queue.put(request)
 
     async def assign(self, node_or_pod, inputs, params, **extensions):
         correlation_id = str(uuid.uuid4()) # Where should we do this?
@@ -290,29 +304,26 @@ class WebsocketPostman(BasePostman):
 
         assigned_inputs = await shrinkInputs(node=node_or_pod, inputs=inputs)
 
+        
        
         #TODO: Implement assigning to pod directly
-        request = AssignationRequestMessage(data={
-                                                "node":node_or_pod.id, 
+        request = AssignMessage(data={
+                                                "node": node_or_pod.id, 
                                                 "inputs": assigned_inputs, 
                                                 "params": dict(params or {}),
-                                                "reference": correlation_id,
-                                                "callback": None,
-                                                "progress": None,
                                             },
                                             meta={
                                                 "reference": correlation_id,
-                                                "auth": {
-                                                    "token": self.token
-                                                },
-                                                "extensions": extensions
+                                                "extensions": {
+                                                    "progress": correlation_id,
+                                                    "callback": correlation_id
+                                                }
                                             })
 
 
         await self.send_to_arnheim(request)
 
 
-
         future.add_done_callback(partial(self.check_if_cancelled, request))  
 
         outputs = await future
